module stepanbarta

using WAV
using Statistics
using Plots
using Images

include("./zaf/zaf.jl")

function mp3towav( source, destination, sample_freq )
    # test if source file exists
    if ( !isfile( source ) ) 
        return false
    end

    command = `mpg123 --single0 --rate $sample_freq -w $destination $source`
    run(command)

    return true
end

function melSpectrgrmFromWav( source_dir, source_file, destination, sample_freq, start, step )
    
    audio_sig, sampling_freq = wavread( "$source_dir$source_file", start * sample_freq: (start+step) *  sample_freq )
    audio_sig = mean(audio_sig, dims=2)

    # Set the parameters for the Fourier analysis
    window_len = nextpow(2, ceil(Int, 0.04*sampling_freq))
    window_fun = zaf.hamming(window_len, "periodic")
    step_len = convert(Int, window_len/2)

    # Compute the mel filterbank
    num_mels = 64
    mel_filbank = zaf.melfilterbank(sampling_freq, window_len, num_mels)

    # Compute the mel spectrogram using the filterbank
    mel_spectrgram = zaf.melspectrogram(audio_sig, window_fun, step_len, mel_filbank)

    # Display the mel spectrogram
    plot_object = heatmap(
        20 * log10.(mel_spectrgram),
        color = :greys,
        legend = false,
        fmt = :png,
        size = (153, 153),
        xticks = false,
        yticks = false
    )

    #save to file
    png("$destination$source_file-$start.png")

    #load image again to crop white borders and set image size to 128x128px
    loaded_png = load("$destination$source_file-$start.png")
    save("$destination$source_file-$start.png", loaded_png[13:end-12,13:end-13])
    return "$source_file-$start.png"
end

end